@@ -27,7 +27,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.59)
       '.rgx' => qr/\G\#\#\#\r?\n((?:.*\r?\n)*?)\#\#\#\r?\n(?:\ *\r?\n)?/
     },
     'block_func' => {
-      '.rgx' => qr/\G<<<([\w\-]+)(?:|\r?\n((?:.*\r?\n)*?))\>\>\>\r?\n/
+      '.rgx' => qr/\G<<<\ *([\w\-]+)\ *(?:(.*?)\ *|\r?\n((?:.*\r?\n)*?))\>\>\>\r?\n/
     },
     'block_head' => {
       '.rgx' => qr/\G(={1,4})\ +(?:(.+?)\ +=+\r?\n|(.+\r?\n(?:[^\s].*\r?\n)*[^\s].*?)\ +=+\r?\n|(.+\r?\n(?:[^\s].*\r?\n)*)(?=[\ \*=\#]|\r?\n|\z))(?:\ *\r?\n)?/
